/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#include "config/option/hostnameoption.h"

#include <string>
#include <vector>

#include <boost/foreach.hpp>

#include <logfunc.hpp>

#include "boost_assert_handler.h"

using namespace std;
using boost::program_options::value;
using boost::program_options::variables_map;
using I2n::Logger::GlobalLogger;

//-----------------------------------------------------------------------------
// HostNameOption
//-----------------------------------------------------------------------------

HostNameOption::HostNameOption() :
    HostConfigurationOption(
        "host.name",
        value< vector<string> >(),
        "Host address."
    )
{
}

HostNameOption::~HostNameOption()
{
}

bool HostNameOption::parse(
        const variables_map& vm,
        Configuration *configuration
)
{
    size_t hosts_names_count = 0;
    bool parsed_success = false;

    // [host] name
    if ( 1 <= vm.count( get_command_string() ) )
    {
        HostList hosts_list;

        vector<string> hosts_names = vm[ get_command_string() ].as< vector<string> > ();
        BOOST_FOREACH( string host_name, hosts_names )
        {
            BOOST_ASSERT( !host_name.empty() );

            HostItem host_item( new Host( host_name ) );
            hosts_list.push_back( host_item );

            GlobalLogger.info() << get_command_string() << "="
                    << host_name << endl;
        }

        configuration->set_hosts( hosts_list );

        hosts_names_count = hosts_names.size();
        parsed_success = true;
    }

    set_hosts_count( hosts_names_count );

    BOOST_ASSERT( hosts_names_count >= static_cast<size_t>( configuration->get_hosts_down_limit() ) );

    return parsed_success;
}
